@@ -11,7 +11,15 @@ logger = logging.getLogger(__name__)
 
 
 class Library:
-    def __init__(self, name, location, sync_type=None, sync_uri=None, auto_sync=True):
+    def __init__(
+        self,
+        name,
+        location,
+        sync_type=None,
+        sync_uri=None,
+        sync_version=None,
+        auto_sync=True,
+    ):
         if sync_type and not sync_type in ["local", "git"]:
             raise ValueError(
                 "Library {} ({}) Invalid sync-type '{}'".format(
@@ -31,6 +39,7 @@ class Library:
         self.location = location
         self.sync_type = sync_type or "local"
         self.sync_uri = sync_uri
+        self.sync_version = sync_version
         self.auto_sync = auto_sync
 
     def update(self, force=False):
@@ -43,9 +52,7 @@ class Library:
 
         # FIXME: Do an initial checkout if missing
         if not os.path.exists(self.location):
-            logger.warning(
-                l("{} does not exist. Ignoring update".format(self.location))
-            )
+            logger.warning(l(f"{self.location} does not exist. Ignoring update"))
             return
 
         if not (self.auto_sync or force):
@@ -83,7 +90,7 @@ class LibraryManager:
             if library:
                 libraries.append(library)
             else:
-                logger.warning("Could not find library {}".format(name))
+                logger.warning(f"Could not find library {name}")
 
         if library_names:
             force = True
