@@ -14,12 +14,25 @@ logger = logging.getLogger(__name__)
 
 
 class Git(Provider):
+    @staticmethod
+    def _checkout_library_version(library):
+        git_args = ["-C", library.location, "checkout", "-q", library.sync_version]
+
+        if library.sync_version:
+            logger.info(
+                "Checkout out {} at version {}".format(
+                    library.name, library.sync_version
+                )
+            )
+            Launcher("git", git_args).run()
+
     @staticmethod
     def init_library(library):
-        logger.info("Cloning library into {}".format(library.location))
+        logger.info(f"Cloning library into {library.location}")
         git_args = ["clone", library.sync_uri, library.location]
         try:
             Launcher("git", git_args).run()
+            Git._checkout_library_version(library)
         except subprocess.CalledProcessError as e:
             raise RuntimeError(str(e))
 
@@ -27,6 +40,7 @@ class Git(Provider):
     def update_library(library):
         git_args = ["-C", library.location, "pull"]
         try:
+            Git._checkout_library_version(library)
             Launcher("git", git_args).run()
         except subprocess.CalledProcessError as e:
             raise RuntimeError(str(e))
@@ -37,8 +51,23 @@ class Git(Provider):
         # TODO : Sanitize URL
         repo = self.config.get("repo")
         logger.info("Checking out " + repo + " to " + local_dir)
-        args = ["clone", "-q", repo, local_dir]
-        Launcher("git", args).run()
+        try:
+            args = [
+                "clone",
+                "-q",
+                "--depth",
+                "1",
+                "--no-single-branch",
+                repo,
+                local_dir,
+            ]
+            Launcher("git", args).run()
+        except RuntimeError as e:
+            try:
+                args = ["clone", "-q", "--no-single-branch", repo, local_dir]
+                Launcher("git", args).run()
+            except:
+                raise e
         if version:
             args = ["-C", local_dir, "checkout", "-q", version]
             Launcher("git", args).run()
